<?php
/**
* Plugin Class for CPT
*/
class Image_Caption_Hover_CPT
{
    
    function __construct(){
        add_action( 'admin_enqueue_scripts', array($this, 'loading_scripts_admin'));
        add_action( 'init', array($this, 'register_ich_cpt') );
        add_action( 'add_meta_boxes', array($this, 'ich_settings_box') );
        add_action( 'save_post', array($this, 'saving_ich_cpt') );
        add_filter('manage_ich_cpt_posts_columns', array($this, 'ich_cpt_column_head'));
        add_action('manage_ich_cpt_posts_custom_column', array($this, 'ich_cpt_column_content'), 10, 2);
        add_action( 'admin_menu', array( $this, 'ich_admin_options' ) );
        add_action('wp_ajax_save_ich_settings', array($this, 'save_ich_settings'));
    }

    /**
    * Registers a new post type ich_cpt
    */
    function register_ich_cpt() {    
        include ICH_PATH.'/inc/register-cpt.php';
    }
    
    /**
     * Loading admin scripts only when we need them
     */
    function loading_scripts_admin($check){
        global $post;
        if ( $check == 'post-new.php' || $check == 'post.php' || 'edit.php') {
            if (isset($post->post_type) && 'ich_cpt' === $post->post_type) {
                wp_enqueue_style( 'wp-color-picker' );
                wp_enqueue_style( 'ichcpt-admin', ICH_URL. '/assets/css/admin.css');
                wp_enqueue_script( 'wp-color-picker-alpha', ICH_URL. '/assets/js/wp-color-picker-alpha.min.js' , array( 'wp-color-picker' ));
                wp_localize_script( 'wp-color-picker-alpha', 'wpColorPickerL10n', array(
                    'clear'            => __( 'Clear' ),
                    'clearAriaLabel'   => __( 'Clear color' ),
                    'defaultString'    => __( 'Default' ),
                    'defaultAriaLabel' => __( 'Select default color' ),
                    'pick'             => __( 'Select Color' ),
                    'defaultLabel'     => __( 'Color value' ),
                ) );
                wp_enqueue_media();

                wp_enqueue_style( 'ich-framework', ICH_URL. '/assets/css/framework.css');

                wp_enqueue_script( 'ichcpt-admin', ICH_URL. '/assets/js/cpt.js', array('jquery', 'wp-color-picker', 'jquery-ui-sortable', 'jquery-ui-accordion', 'jquery-ui-tooltip'));
            }
        }
        if ($check == 'ich_cpt_page_ich_admin_settings') {
            wp_enqueue_script( 'ich-admin-settings', ICH_URL.'/assets/js/settings.js', array('jquery') );
        }
    }

    /**
     * Adding Metaboxes for settings
     */
    function ich_settings_box() {
        add_meta_box( 'ichcpt_options', esc_html__( 'Images', 'image-caption-hover' ), array($this, 'ichcpt_contents_mb'), 'ich_cpt');
        add_meta_box( 'ichcpt_shortcode', 'Shortcode', array($this, 'ichcpt_shortcode_mb'), 'ich_cpt', 'side');
        add_meta_box( 'ichcpt_settings', esc_html__( 'Settings', 'image-caption-hover' ), array($this, 'ichcpt_settings_mb'), 'ich_cpt');
    }

    /**
     * Displaying shortcode in metabox
     */
    function ichcpt_shortcode_mb(){
        global $post;
        if (isset($post->ID)) {
            echo '<p class="shortcode-wrap">[ichcpt id="'.$post->ID.'"]</p>';
            
        } else {
            echo esc_html__( 'Please Save settings to get shortcode', 'image-caption-hover' );
        }
    }

    /**
     * Rendering settings
     */
    function ichcpt_settings_mb(){
        include ICH_PATH.'/inc/settings-box.php';
    }

    /**
     * Rendering images settings
     */
    function ichcpt_contents_mb() {
        // Use nonce for verification
        wp_nonce_field( plugin_basename( __FILE__ ), 'ich_cpt_nonce' );
        include ICH_PATH.'/inc/images-box.php';
    }

    /**
     * Saving all data in cpt
     */
    function saving_ich_cpt( $post_id ) {
        // verify if this is an auto save routine. 
        // If it is our form has not been submitted, so we dont want to do anything
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
            return;

        // verify this came from the our screen and with proper authorization,
        // because save_post can be triggered at other times
        if ( !isset( $_POST['ich_cpt_nonce'] ) )
            return;

        if ( !wp_verify_nonce( $_POST['ich_cpt_nonce'], plugin_basename( __FILE__ ) ) )
            return;

        // OK, we're authenticated: we need to find and save the data

        $wcp_images = $_POST['ich_cpt'];
        $wcp_settings = $_POST['ichcpt_settings'];
        $wcp_images = array_values($wcp_images);

        update_post_meta($post_id,'ich_cpt',$wcp_images);
        update_post_meta($post_id,'ichcpt_settings',$wcp_settings);
    }

    function ich_cpt_column_head($defaults){
        $defaults['ich_column'] = 'Shortcode';
        return $defaults;       
    }

    function ich_cpt_column_content($column_name, $gallery_id){
        if ($column_name == 'ich_column') {
            echo '[ichcpt id="'.$gallery_id.'"]';
        }
    }

    function get_all_fields_data(){
        $all_fields = array();

        include ICH_PATH.'/inc/admin-settings-array.php';

        return $all_fields;
    }

    function render_settings_fields($key){
        global $post;
        $all_fields = $this->get_all_fields_data();
        $wcp_settings = get_post_meta($post->ID, 'ich_cpt' ,true);
        $saved_opt = (isset($wcp_settings[$key])) ? $wcp_settings[$key] : array() ;

        include ICH_PATH.'/inc/render-settings-input.php';
        
    }

    function get_free_effects(){
        $hoverEffects = array();

        include ICH_PATH.'/inc/hover-styles.php';

        return $hoverEffects;
    }

    function get_ihover_effects(){
        $hoverEffects = array();

        include ICH_PATH.'/inc/ihover-styles.php';

        return $hoverEffects;
    }

    function ich_admin_options(){
        add_submenu_page('edit.php?post_type=ich_cpt', 'Image Caption Hover Settings', esc_html__( 'Settings', 'image-caption-hover' ), 'manage_options', 'ich_admin_settings', array($this, 'render_ich_admin_settings') );
    }

    function render_ich_admin_settings(){
        include ICH_PATH.'/inc/global-settings.php';
    }

    function save_ich_settings(){
        if (isset($_REQUEST['role'])) {
            update_option( 'wcp_ich_admin_settings', $_REQUEST['role'] );
            update_option( 'wcp_ich_admin_settings_all', $_REQUEST );
        }

        die(0); 
    }    
}
?>